@@ -223,7 +223,7 @@ func (u *unmarshalGen) tuple(s *Struct) {
 	u.p.declare(sz, u32)
 	u.assignAndCheck(sz, arrayHeader)
 	if s.AsVarTuple {
-		u.p.printf("\nif %[1]s == 0 {\no = bts\nreturn\n}", sz)
+		u.p.printf("\nfor %[1]s > 0 {", sz) // start the block
 	} else {
 		u.p.arrayCheck(strconv.Itoa(len(s.Fields)), sz)
 	}
@@ -265,11 +265,12 @@ func (u *unmarshalGen) tuple(s *Struct) {
 			u.p.printf("\n}")
 		}
 		if s.AsVarTuple {
-			u.p.printf("\nif %[1]s--; %[1]s == 0 {\no = bts\nreturn\n}", sz)
+			u.p.printf("\nif %[1]s--; %[1]s == 0 { break }", sz) // exit from the block
 		}
 	}
 	if s.AsVarTuple {
 		u.p.printf("\nfor ; %[1]s > 0; %[1]s-- {\nbts, err = msgp.Skip(bts)\nif err != nil {\nerr = msgp.WrapError(err)\nreturn\n}\n}", sz)
+		u.p.printf("\n}") // end the block
 	}
 }
 
